@@ -1,5 +1,5 @@
 /*
- * Copyright 2021 Univention GmbH
+ * Copyright 2021-2022 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -30,16 +30,11 @@ import { ActionContext } from 'vuex';
 
 import { PortalModule, RootState } from '../../root.models';
 
-interface Message {
-  id: string,
-  msg: string,
-}
-
 export interface Activity {
   level: string,
   focus: Record<string, string>,
   region: string | null,
-  messages: Record<string, Message>,
+  message: string,
 }
 
 type ActivityActionContext = ActionContext<Activity, RootState>;
@@ -54,8 +49,8 @@ const activity: PortalModule<Activity> = {
   state: {
     level: 'portal',
     focus: {},
-    region: 'portal-header',
-    messages: {},
+    region: '',
+    message: '',
   },
 
   mutations: {
@@ -68,11 +63,8 @@ const activity: PortalModule<Activity> = {
     SET_LEVEL(state: Activity, level: string): void {
       state.level = level;
     },
-    ADD_MESSAGE(state: Activity, message: Message): void {
-      state.messages[message.id] = message;
-    },
-    REMOVE_MESSAGE(state: Activity, id: string): void {
-      delete state.messages[id];
+    SET_MESSAGE(state: Activity, message: string): void {
+      state.message = message;
     },
     SAVE_FOCUS(state: Activity, payload: SaveFocusArgs): void {
       let region = payload.region;
@@ -110,7 +102,7 @@ const activity: PortalModule<Activity> = {
     level: (state: Activity) => state.level,
     focus: (state: Activity) => state.focus,
     region: (state: Activity) => state.region,
-    announce: (state: Activity) => Object.values(state.messages),
+    message: (state: Activity) => state.message,
   },
 
   actions: {
@@ -124,11 +116,8 @@ const activity: PortalModule<Activity> = {
     setLevel({ commit }: ActivityActionContext, level: string): void {
       commit('SET_LEVEL', level);
     },
-    addMessage({ commit }: ActivityActionContext, message: Message): void {
-      commit('ADD_MESSAGE', message);
-    },
-    removeMessage({ commit }: ActivityActionContext, id: string): void {
-      commit('REMOVE_MESSAGE', id);
+    setMessage({ commit }: ActivityActionContext, message: string): void {
+      commit('SET_MESSAGE', message);
     },
     async focusElement({ getters }: ActivityActionContext, region: string | null): Promise<void> {
       if (!region) {
