@@ -1,5 +1,5 @@
 /*
- * Copyright 2021 Univention GmbH
+ * Copyright 2021-2022 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -33,4 +33,6 @@ export interface Tooltip {
     backgroundColor: string | null,
     description: string,
     ariaId: string,
+    position: Record<string, number>,
+    isMobile: boolean | null,
 }
