@@ -1,5 +1,5 @@
 /*
-  Copyright 2021 Univention GmbH
+  Copyright 2021-2022 Univention GmbH
 
   https://www.univention.de/
 
@@ -41,7 +41,8 @@ describe('Test Tabs', () => {
       cy.setCookie('univentionCookieSettingsAccepted', 'doesthisneedavalue');
       cy.visit('/');
       // first click results to first tab and first Iframe (first element in array)
-      cy.get('.portal-category .portal-tile').last().click();
+      cy.get('.portal-category .portal-tile').last()
+        .click();
       cy.get('#iframe-1').should('be.visible');
       // click to portal
       cy.get('.portal-title__portal-name').click();
@@ -56,7 +57,8 @@ describe('Test Tabs', () => {
       cy.get('[href="https://doc.owncloud.com/server/10.0/user_manual/"]').click();
       cy.get('iframe').should('be.visible');
       // now we have two tabs and can switch between them
-      cy.get('[data-test="header-tabs"]').children().should('have.length', 2)
+      cy.get('[data-test="header-tabs"]').children()
+        .should('have.length', 2);
       cy.get('#headerTab__1').click();
       cy.get('#iframe-1').should('be.visible');
       cy.get('iframe').should('be.focused');
@@ -65,13 +67,17 @@ describe('Test Tabs', () => {
       cy.get('#iframe-2').should('be.visible');
       cy.get('[data-test="close-tab-2"]').click();
       cy.get('#portalCategories').should('be.visible');
-      cy.get('[data-test="header-tabs"]').children().should('have.length', 1)
-      cy.get('[data-test="portal-iframes"]').children().should('have.length', 1)
+      cy.get('[data-test="header-tabs"]').children()
+        .should('have.length', 1);
+      cy.get('[data-test="portal-iframes"]').children()
+        .should('have.length', 1);
       // closing remaining tab
       cy.get('[data-test="close-tab-1"]').click();
       cy.get('#portalCategories').should('be.visible');
-      cy.get('[data-test="header-tabs"]').children().should('have.length', 0)
-      cy.get('[data-test="portal-iframes"]').children().should('have.length', 0)
+      cy.get('[data-test="header-tabs"]').children()
+        .should('have.length', 0);
+      cy.get('[data-test="portal-iframes"]').children()
+        .should('have.length', 0);
     });
   });
   it('test store', () => {
@@ -84,12 +90,20 @@ describe('Test Tabs', () => {
       cy.setCookie('univentionCookieSettingsAccepted', 'doesthisneedavalue');
       cy.visit('/');
       const getStore = () => cy.window().its('store');
-      getStore().its('state').should('have.any.keys', ['activeTabIndex', 'tabs', 'scrollPosition']);
+      getStore().its('state')
+        .should('have.any.keys', ['activeTabIndex', 'tabs', 'scrollPosition']);
       // open Tab to see if it correctly in store
-      getStore().its('state').its('tabs').its('tabs').should('have.length', 0);
-      cy.get('.portal-category .portal-tile').last().click();
+      getStore().its('state')
+        .its('tabs')
+        .its('tabs')
+        .should('have.length', 0);
+      cy.get('.portal-category .portal-tile').last()
+        .click();
       cy.get('#iframe-1').should('be.visible');
-      getStore().its('state').its('tabs').its('tabs').should('have.length', 1);
+      getStore().its('state')
+        .its('tabs')
+        .its('tabs')
+        .should('have.length', 1);
     });
   });
 
@@ -103,28 +117,38 @@ describe('Test Tabs', () => {
       cy.setCookie('univentionCookieSettingsAccepted', 'doesthisneedavalue');
 
       cy.viewport('iphone-x', 'landscape');
-      cy.visit('/'); 
+      cy.visit('/');
       const getStore = () => cy.window().its('store');
-      getStore().its('state').should('have.any.keys', ['activeTabIndex', 'tabs', 'scrollPosition']);
+      getStore().its('state')
+        .should('have.any.keys', ['activeTabIndex', 'tabs', 'scrollPosition']);
       // open Tab to see if it correctly in store
-      getStore().its('state').its('tabs').its('scrollPosition').should('eq', 0);
-      cy.get('.portal-category .portal-tile').last().click();
+      getStore().its('state')
+        .its('tabs')
+        .its('scrollPosition')
+        .should('eq', 0);
+      cy.get('.portal-category .portal-tile').last()
+        .click();
       // cy.get('#iframe-1').should('be.visible');
-      getStore().its('state').its('tabs').its('scrollPosition').should('be.greaterThan', 0);
+      getStore().its('state')
+        .its('tabs')
+        .its('scrollPosition')
+        .should('be.greaterThan', 0);
     });
   });
-
+  /* eslint-disable jest/expect-expect */
   it('A11y Test', () => {
     cy.injectAxe();
-    cy.checkA11y('[data-test="header-tabs"]', 
-    {
-      runOnly: {
-        type: 'tag',
-        values: ['wcag21aa'],
-      }
-    },
-    cy.terminalLog, {
-      skipFailures: false
-    });
+    cy.checkA11y('[data-test="header-tabs"]',
+      {
+        runOnly: {
+          type: 'tag',
+          values: ['wcag21aa'],
+        },
+      },
+      cy.terminalLog, {
+        skipFailures: false,
+      });
   });
+
+  /* eslint-enable jest/expect-expect */
 });
